@@ -5,6 +5,7 @@ import uuid
 import argparse
 import logging
 import copy
+from datetime import datetime
 
 from wzdx.tools import polygon_tools, date_tools, array_tools
 
@@ -111,6 +112,13 @@ def parse_rtdh_arguments():
     return args.navjoyFile, args.outputDir
 
 
+def date_to_unix(time):
+    if not time or type(time) != datetime:
+        return None
+
+    return round(time.timestamp() * 1000)
+
+
 # take in individual message, spit out list of altered unique messages to be translated
 # This function iterates over the list of NUMBERED_KEY_NAMES and correlates them to CORRECT_KEY_NAMES. For each
 # set of numbered key names, generate a copy of the original message, check if the numbered keys exist, if they do
@@ -121,9 +129,12 @@ def parse_rtdh_arguments():
 # TODO: consider removing duplicate messages
 def expand_speed_zone(message):
     messages = []
-
     for key_set in NUMBERED_KEY_NAMES:
+        # print(key_set)
         if not message.get('data', {}).get(key_set['street_name']):
+            # print(key_set['street_name'])
+            # # print(message.get('data', {}))
+            # print("EXITING")
             continue
         new_message = copy.deepcopy(message)
         for key, value in key_set.items():
@@ -253,8 +264,8 @@ def create_rtdh_standard_msg(pd):
             "header": {
                 "description": pd.get("data/descriptionForProject", default=""),
                 "justification": pd.get("data/reductionJustification"),
-                "start_timestamp": date_tools.date_to_unix(start_date),
-                "end_timestamp": date_tools.date_to_unix(end_date),
+                "start_timestamp": date_to_unix(start_date),
+                "end_timestamp": date_to_unix(end_date),
             },
             "detail": {
                 "road_name": pd.get("data/streetNameFrom"),
